/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.model;

import java.math.BigDecimal;

/**
 * Representation of a transaction.
 * 
 * A Transaction is a query from the MONEY component that represents
 * the information used for a proper transaction.
 * 
 * Transactions automatically update stocks as well as the Registry
 * when applicable.
 * 
 * @author BEAUVAIS ANTOINE
 */
public class Transaction {
    
    /**
     * Item ID.
     */
    private final Integer item;
    
    /**
     * Transaction type.
     */
    private final Integer type;
    
    /**
     * Transaction's amount.
     */
    private final BigDecimal amount;
    
    /**
     * Number of items.
     */
    private final Integer quantity;
    
    /**
     * Class constructor.
     * @param item Item's identifier.
     * @param type Transaction type.
     * @param amount Transaction's amount.
     * @param quantity Quantity of items involved.
     */
    public Transaction(Integer item, Integer type, BigDecimal amount,
            Integer quantity)
    {
        this.item = item;
        this.type = type;
        this.amount = amount;
        this.quantity = quantity;
    }
    
    /**
     * Returns the Transaction's item ID.
     * @return the item ID.
     */
    public Integer getItem()
    {
        return this.item;
    }
    
    /**
     * Returns the Transaction's type.
     * @return the transaction's type.
     */
    public Integer getType()
    {
        return this.type;
    }
    
    /**
     * Returns the Transaction's amount of money.
     * @return the amount.
     */
    public BigDecimal getAmount()
    {
        return this.amount;
    }
    
    /**
     * Returns the number of items in the Transaction.
     * @return the number of items.
     */
    public Integer getQuantity()
    {
        return this.quantity;
    }
    
    /**
     * Checks that the Transaction is valid.
     * @return whether the Transaction is valid.
     */
    public boolean checkIfValid()
    {
        return (this.item != null && this.type != null
                && this.amount != null && this.quantity != null);
    }
    
}
